{ config, lib, modulesPath, pkgs, ... }:

{
  imports = [
    (modulesPath + "/installer/scan/not-detected.nix")
  ];

  boot = {
    kernelModules = [ "kvm-intel" ];
    extraModulePackages = [ ];
    loader.grub.device = "/dev/disk/by-id/nvme-Samsung_SSD_970_EVO_Plus_250GB_S4EUNJ0N412342P";
    initrd = {
      availableKernelModules = [ "aesni_intel" "ahci" "ehci_pci" "nvme" "sd_mod" "sr_mod" "usb_storage" "usbhid" "xhci_pci" ];
      kernelModules = [ "dm-snapshot" ];
      luks.devices = {
        root = {
          name = "root";
          device = "/dev/disk/by-uuid/1607bb2a-329b-4252-b11a-b43eb6b7bf0c";
          preLVM = true;
          allowDiscards = true;
        };
      };
    };
  };

  fileSystems = {
    "/" = {
      device = "/dev/disk/by-uuid/9e6b279e-6995-44da-b673-21b9e23a5278";
      fsType = "btrfs";
      options = [ "discard=async" "noatime" "compress=zstd" ];
    };

    "/boot" = {
      device = "/dev/disk/by-uuid/7b8b75d2-f779-4a49-b09d-b2a1bbd801bb";
      fsType = "ext2";
    };

    "/data" = {
      device = "/dev/mapper/data";
      fsType = "btrfs";
      options = [ "compress=zstd" ];
      encrypted = {
        label = "data";
        enable = true;
        blkDev = "/dev/disk/by-uuid/7f4ba71e-3aca-4294-b37f-49f37b584dbd";
        keyFile = "/mnt-root/root/luks-data";
      };
    };

    "/data/ssd" = {
      device = "/dev/mapper/data-ssd";
      fsType = "btrfs";
      options = [ "discard=async" "noatime" "compress=zstd" ];
      encrypted = {
        # !!! HACK
        label = "data-ssd --allow-discards";
        enable = true;
        blkDev = "/dev/disk/by-uuid/41baa168-7fa0-4eb3-b314-50766ddf126d";
        keyFile = "/mnt-root/root/luks-data";
      };
    };
  };

  swapDevices = [
    { device = "/dev/disk/by-uuid/2774d182-ddc9-4d79-886e-995fcd60a88a"; }
  ];

  powerManagement.cpuFreqGovernor = lib.mkDefault "performance";

  # GPU
  hardware.opengl =
    let
      # nixpkgs PR adding mesa clover support
      # (https://github.com/NixOS/nixpkgs/pull/82729) rebased onto nixos-21.05
      pkgsMesaClover = import
        (pkgs.fetchFromGitHub {
          owner = "sbruder";
          repo = "nixpkgs";
          rev = "e2894ba6626028e081b8ff124a39d2b523a0371c";
          sha256 = "sha256-brM17UTESqtJ8jXbBAl2xDW7ziCBWROb2W+06vIEfjU=";
        })
        { inherit (pkgs) system; };
    in
    {
      package = pkgsMesaClover.mesa_opencl.drivers;
      extraPackages = [
        pkgsMesaClover.mesa_opencl
      ];
    };

  environment.systemPackages = with pkgs; [
    clinfo
    radeontop
    rocm-smi
  ];
}
